# Datenanalyse von Kopf bis Fuß, Seite 265: 
# R-Skript zum Importieren der Gehaltserhöhungsdaten 
# (Kommentare zum Code siehe unten) 

dataURL 	<- "http://examples.oreilly.de/german_examples/hfdataanalysisger/Kap09_Gehalt.csv"; 
Erhöhung 	<- read.csv(file   = dataURL, fileEncoding = "UTF-8", 
						header = TRUE, row.names = 1, sep = ";", dec = ","); 



# ======================================================================================
# 
# Was passiert hier? In Kürze Folgendes: 
# (1) Die Gehaltserhöhungsdaten werden von der deutschen O'Reilly-Seite geladen 
# (2) ... und anschließend von R als Data-Frame ("Datentabelle") interpretiert 
#     und unter dem Namen "Erhöhung" abgelegt 
# 
# 
# Ausführliche Anmerkungen zum Ablauf des Codes: 
# 
# -- read.csv()  liest Dateien im Format CSV (Comma Separated Values) ein, 
#    das ist ein tabellarisches Textformat, in dem die Datenspalten durch 
#    Semikolons oder Kommata getrennt werden. 
#    read.csv() kann Dateien einlesen, die auf Ihrem Rechner gespeichert 
#    sind, kann aber auch Daten aus dem Netz laden -- sehr praktisch! 
# 
# -- Die URL auf die Datendatei legen wir vorab außerhalb des Funktions-
#    aufrufs in der Variable "dataURL" ab und übergeben sie später mit 
#      file = dataURL 
#    an read.csv(). Man könnte die URL auch direkt in den read.csv()-Aufruf 
#    schreiben, aber so wie hier liest es sich leichter. 
# 
# -- Wir müssen sicherstellen, dass die Daten in der richtigen Zeichenkodierung 
#    in Ihrer R-Sitzung landen. Dazu teilen wir read.csv() mit, dass die Datei 
#    in der "plattformneutralen" Unicode-Codierung UTF-8 abgespeichert wurde. 
# 
# -- header=TRUE  besagt, dass die erste Zeile in der Datendatei die 
#    Spaltennamen enthält. 
# 
# -- row.names=1  weist R an, aus dem Inhalt der ersten Spalte der eingelesenen 
#    Datei die Namen der Fälle/Zeilen zu erzeugen (hier sind das lediglich 
#    laufende Nummern). 
# 
# -- Das Argument  sep=";"  teilt R mit, dass die Daten in der Datei durch 
#    ein Semikolon getrennt werden. 
# 
# -- Das Argument  dec=","  schließlich informiert R, dass Dezimalstellen durch 
#    ein Komma getrennt werden (nicht durch den im englischsprachigen Raum 
#    geltenden und in R voreingestellten Punkt -- eine typische Fehlerquelle). 
# 
# 
# Der eingelesene Data-Frame liegt anschließend in der Variable "Erhöhung". 
# Einzelne Spalten können über die Syntax 
# 
#   <Data-Frame>$<Variablen- bzw. Spaltenname>  
# 
# angesprochen werden (ohne die spitzen Klammern). 
# Spaltenbereiche, auch unzusammenhängende, lassen sich z.B. über die Syntax 
# 
#   Erhöhung[ c( "<Variablenname1>", "<Variablenname2>", ... ) ] 
# 
# extrahieren (ohne die spitzen Klammern, aber mit den Anführungszeichen!). 
# 
# Eine Alternative ist die Funktion "subset". Wenn Sie mehr darüber wissen 
# wollen, können Sie sich mit 
#   ?subset 
# die Hilfeseite anzeigen lassen -- experimentieren Sie ein bisschen. 
# 
# 
# Viel Erfolg und viel Spaß mit R! 
# 
# 
# ======================================================================================
