# ==============================================================================
# Gehaltserhöhungsdaten laden 
# ------------------------------------------------------------------------------

# Sie müssen zuerst das Arbeitsverzeichnis von R auf den Ordner 
# umstellen, in dem Sie die Datendatei abgelegt haben 
setwd("Vollständiger Pfad auf den Ordner, in dem die Datendatei liegt"); 


# Jetzt laden Sie die Datei, anschließend sehen Sie mit head() 
# kurz nach, ob alles ordnungsgemäß aussieht 
Erhöhung            <- read.csv(file = "Kap09_Gehalt.csv", 
                        header = TRUE, row.names = 1, sep = ";", 
                        dec = ",", fileEncoding = "UTF-8"); 
head(Erhöhung, n = 10); 



# ==============================================================================
# Histogramm S. 266
# 
# Wir zeigen drei vom Buch abweichende Varianten des Histogramms auf 
# S. 266, die drei unterschiedliche Programmiertechniken demonstrieren. 
# 
# Die Funktionen (und Subsysteme) zum Erzeugen von Diagrammen in R 
# sind sehr mächtig -- so mächtig, dass zu einzelnen Aspekten (!) 
# ganze Bücher geschrieben wurden. Wir können Ihnen hier nur einen 
# kleinen und sehr oberflächlichen Ausschnitt aus den Möglichkeiten 
# vorstellen, der aber hoffentlich Appetit auf mehr macht. 
# 
# ==============================================================================
# Variante 1 -- die kurze, knackige: ein Aufruf, und fertig... 
# 
# Wir rufen die Funktion "hist()" mit folgenden Argumenten auf: 
#   Argument "main"     Überschrift des Diagramms 
#   Argument "xlab"     Titel der x-Achse 
#   Argument "ylab"     Titel der y-Achse 
# 
#   Argument "las"      (oder 'la'bel-'s'tyle?) steuert die Ausrichtung der 
#                       Zahlen an den Achsen, "1" bedeutet "beide waagerecht" 
# 
#   Argument "breaks"   steuert die Intervalleinteilung für die x-Daten 
# 
#   Argument "xlim"     steuert den x-Wertebereich, der auf der Plot-Fläche 
#                       abgebildet werden kann (könnte man hier auch weglassen) 
# 
#   Argument "col"      Balkenfarbe (hier hellgrau) 
# 
# Was wir mit dieser Technik *nicht* steuern können, sind Feinheiten der 
# Gestaltung wie die Achseneinteilung, Schriftgrößen, etc. Diagramme wie 
# dieses hier werden oft in der Explorationsphase angelegt und später 
# in R verfeinert, z.B. für einen Bericht oder eine Publikation. 
# 
# ------------------------------------------------------------------------------

hist(x      = Erhöhung$Ergebnis, 
    main    = "Häufigkeitsverteilung \nerhaltener Gehaltserhöhungen", 
    xlab    = "Gehaltserhöhung (%)", 
    ylab    = "absolute  Häufigkeit", 
    las     = 1, 
    
    breaks  = seq(-2, 26, 0.5), 
    xlim    = c(  -2, 26), 
    col     = "light grey"); 



# ==============================================================================
# Variante 2 -- die flexible: Werte für die Funktionsargumente in Variablen legen 
# 
# Wir bleiben zur Erzeugung des Histogramms bei einem einzigen, kompakten 
# Aufruf, auch die Parameter, die wir an die Funktion übergeben, bleiben 
# gleich. 
# 
# Allerdings legen wir jetzt *alle Parameter* vorher in Variablen ab und 
# übergeben *die* an die Grafikfunktion. Wenn wir z.B. Serien gleichartiger 
# Diagramme anlegen wollen, bei denen sich immer nur wenig ändert, können 
# wir so leicht für Einheitlichkeit sorgen. 
# 
# Eine kleine kosmetische Änderung gegenüber Variante 1 nehmen wir aber 
# doch vor: wir definieren die Balkenfarbe diesmal nicht mit einem der 
# Farbnamen, die R versteht, diesmal definieren wir einen RGB-Farbwert. 
# 
# Los geht's... 
# 
# ==============================================================================

#     Hier legen wir die Basisparameter für unsere Grafik(en) fest 
Überschrift <- "Häufigkeitsverteilung \nerhaltener Gehaltserhöhungen"; 
xTitel      <- "Gehaltserhöhung (%)"; 
yTitel      <- "absolute  Häufigkeit"; 
xyLabel     <- 1; 
Kategorien  <- seq(-2, 26, 0.5); 
xGrenzen    <- c(  -2, 26); 
Balkenfarbe <- rgb(r = 0.9, g = 0.9, b = 0.9, maxColorValue = 1.0); 


# (a) Alle Rohdaten plotten 
Daten       <- Erhöhung$Ergebnis; 
Untertitel  <- ""; 
hist(x      = Daten, 
    main    = paste("", Überschrift, Untertitel), 
    xlab    = xTitel, 
    ylab    = yTitel, 
    las     = xyLabel, 
    
    breaks  = Kategorien, 
    xlim    = xGrenzen, 
    col     = Balkenfarbe); 



# (b) nur Rohdaten aus dem Jahr 2007 
#     Selber Aufruf wie (a), aber mit anderen Daten 
#     und anderem Untertitel 
Daten       <- Erhöhung$Ergebnis[ Erhöhung$Jahr == 2007 ]; 
Untertitel  <- "\nim Jahr 2007"; 
hist(x      = Daten, 
    main    = paste("", Überschrift, Untertitel), 
    xlab    = xTitel, 
    ylab    = yTitel, 
    las     = xyLabel, 
    
    breaks  = Kategorien, 
    xlim    = xGrenzen, 
    col     = Balkenfarbe); 



# (c) nur Rohdaten aus dem Jahr 2008 
#     Selber Aufruf wie (b), aber wieder mit anderen Daten 
#     und anderem Untertitel 
Daten       <- Erhöhung$Ergebnis[ Erhöhung$Jahr == 2008 ]; 
Untertitel  <- "\nim Jahr 2008"; 
hist(x      = Daten, 
    main    = paste("", Überschrift, Untertitel), 
    xlab    = xTitel, 
    ylab    = yTitel, 
    las     = xyLabel, 
    
    breaks  = Kategorien, 
    xlim    = xGrenzen, 
    col     = Balkenfarbe); 



# ==============================================================================
# Variante 3 -- die schrittweise: Feinkontrolle über alle Elemente im Diagramm 
# 
# Oft möchte man maximale Kontrolle über alle Elemente eines Diagramms. 
# Das erreicht man, indem man es quasi in seine Einzelteile zerlegt und 
# diese schrittweise im Plot einzeichnet. 
# 
# Beginnen muss man bei dieser Strategie mit einem Funktionsaufruf, der 
# die Daten selbst plottet, dann können weitere Aufrufe für Achsen, 
# Beschriftungen, Legenden oder sogar weitere Daten folgen. 
# 
# In unserem Histogramm-Aufruf brauchen wir dafür ein paar neue Argumente: 
#   Argument "axes"     Wollen wir, dass Achsen eingezeichnet werden? 
#                       (TRUE/FALSE) 
# 
#   Argument "ann"      Wollen wir eine Überschrift und betitelte Achsen? 
#                       (TRUE/FALSE) 
# 
# 
# Die Argumente der Funktionsaufrufe, die auf "hist()" folgen, sehen Sie 
# am besten auf den Hilfeseiten von R nach (z.B., indem Sie auf der 
# Befehlszeile 
#   ?mtext 
# eingeben.) 
# 
# ==============================================================================

#     Hier legen wir wieder die Basisparameter für unsere Grafik(en) fest 
Überschrift <- "Häufigkeitsverteilung \nerhaltener Gehaltserhöhungen"; 
xTitel      <- "Gehaltserhöhung (%)"; 
yTitel      <- "absolute  Häufigkeit"; 
xyLabel     <- 1; 
Kategorien  <- seq(-2, 26, 0.5); 
xGrenzen    <- c(  -2, 26); 
Balkenfarbe <- rgb(r = 0.9, g = 0.9, b = 0.9, maxColorValue = 1.0); 

xTicks      <- seq(0, 25, 5); 


#     Und jetzt bauen wir das Diagramm schrittweise auf, 
#     Element für Element, eine Anweisung nach der anderen 
# (a) zuerst nur die Daten/Balken, sonst nichts 
Daten       <- Erhöhung$Ergebnis; 
Untertitel  <- ""; 

hist(x      = Daten, 
    axes    = FALSE, 
    ann     = FALSE, 
    
    breaks  = Kategorien, 
    xlim    = xGrenzen, 
    col     = Balkenfarbe); 


# (b) Jetzt die Achsen mit den Maßeinteilungen 
#     (x-Achse, y-Achse) 
axis(side = 1, las = 1, at = xTicks); 
axis(side = 2, las = 1); 


# (c) Zum Schluß die Achsentitel und die Überschrift 
#     (x-Achse, y-Achse, Überschrift) 
mtext(text = xTitel,      side = 1, las = 0, font = 1, line = 2.25); 
mtext(text = yTitel,      side = 2, las = 0, font = 1, line = 2.75); 
mtext(text = Überschrift, side = 3, las = 0, font = 2, line = 1.25, cex = 1.2); 


# (d) Zugabe? Bitte sehr ;-) 
#     Wir markieren jetzt mal (wie auf S. 268) den Mittelwert 
#     plus/minus der einfachen Standardabweichung 

# Erst ein paar Parameter festlegen 
MW          <- mean(Daten); # Mittelwert 
SD          <- sd(  Daten); # Standardabweichung 
unten       <- -18;         # unterer Rand der Standardabweichungsfläche 
oben        <- 480;         # oberer  Rand der Standardabweichungsfläche 
Fläche_rot  <- rgb(0.80, 0.00, 0.00, alpha = 0.25, maxColorValue = 1); 
Linie_weiss <- rgb(1.00, 1.00, 1.00, alpha = 1.00, maxColorValue = 1); 


# Jetzt ein rot schattiertes Rechteck ("rect()") für die Standardabweichung 
rect(
    xleft   = (MW - SD), 
    ybottom = unten, 
    xright  = (MW + SD), 
    ytop    = oben, 
    col     = Fläche_rot, 
    border  = NA); 


# Und zum Abschluss eine gestrichelte ("lty = "84" ") weiße Linie ("lines()") 
# für den Mittelwert 
lines(
    x       = rep(MW, 2), 
    y       = c(unten, oben), 
    lwd     = 2, 
    lty     = "63", 
    col     = Linie_weiss); 


# Voila. 
# Stöbern Sie in den Hilfeseiten der Grafikfunktionen, 
# und experimentieren Sie. 
# Viel Spaß dabei! 



# ==============================================================================
